@@ -4,7 +4,7 @@ import kate
 import pep8
 
 
-from kate_settings_plugins import KATE_ACTIONS
+from kate_settings_plugins import KATE_ACTIONS, IGNORE_PEP8_ERRORS
 from pyte_plugins.check_plugins import commons
 from pyte_plugins.check_plugins.check_all_plugins import checkAll
 
@@ -58,15 +58,22 @@ def checkPep8(currentDocument=None, refresh=True):
         return
 
     errors_to_show = []
-
+    if IGNORE_PEP8_ERRORS:
+        pep8.options.ignore.extend(IGNORE_PEP8_ERRORS)
+        pep8.options.ignore = list(set(pep8.options.ignore))
     # Paint errors found
     for error in errors:
+        if pep8.ignore_code(error[2]):
+            continue
         errors_to_show.append({
             "line": error[0],
             "column": error[1],
             "filename": path,
             "message": error[3],
             })
-    commons.showErrors('Pep8 Errors:', errors_to_show,
-                       mark_key, currentDocument,
-                       move_cursor=move_cursor)
+    if errors_to_show:
+        commons.showErrors('Pep8 Errors:', errors_to_show,
+                            mark_key, currentDocument,
+                            move_cursor=move_cursor)
+    else:
+        commons.showOk('Pep8 Ok')
